@@ -1,6 +1,6 @@
 from django.contrib import admin
 
-class GuardianModelAdmin(admin.ModelAdmin):
+class GuardianAdminMixin:
     def save_model(self, request, obj, form, change):
         obj._save()
 
@@ -33,4 +33,7 @@ class GuardianModelAdmin(admin.ModelAdmin):
     #     ordering = self.ordering or () # otherwise we might try to *None, which is bad ;)
     #     if ordering:
     #         qs = qs.order_by(*ordering)
-    #     return qs
\ No newline at end of file
+    #     return qs
+
+class GuardianModelAdmin(admin.ModelAdmin, GuardianAdminMixin):
+    pass
\ No newline at end of file
